# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/reflection/v2alpha1/reflection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0cosmos/base/reflection/v2alpha1/reflection.proto\x12\x1f\x63osmos.base.reflection.v2alpha1\x1a\x1cgoogle/api/annotations.proto\"\xb0\x03\n\rAppDescriptor\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\x12?\n\x05\x63hain\x18\x02 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\x12?\n\x05\x63odec\x18\x03 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\x12O\n\rconfiguration\x18\x04 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\x12P\n\x0equery_services\x18\x05 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\x12\x39\n\x02tx\x18\x06 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"^\n\x0cTxDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12<\n\x04msgs\x18\x02 \x03(\x0b\x32..cosmos.base.reflection.v2alpha1.MsgDescriptor\"]\n\x0f\x41uthnDescriptor\x12J\n\nsign_modes\x18\x01 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.SigningModeDescriptor\"b\n\x15SigningModeDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12+\n#authn_info_provider_method_fullname\x18\x03 \x01(\t\"\x1d\n\x0f\x43hainDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x0f\x43odecDescriptor\x12H\n\ninterfaces\x18\x01 \x03(\x0b\x32\x34.cosmos.base.reflection.v2alpha1.InterfaceDescriptor\"\xf4\x01\n\x13InterfaceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12j\n\x1cinterface_accepting_messages\x18\x02 \x03(\x0b\x32\x44.cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor\x12_\n\x16interface_implementers\x18\x03 \x03(\x0b\x32?.cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor\"D\n\x1eInterfaceImplementerDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x10\n\x08type_url\x18\x02 \x01(\t\"W\n#InterfaceAcceptingMessageDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x1e\n\x16\x66ield_descriptor_names\x18\x02 \x03(\t\"@\n\x17\x43onfigurationDescriptor\x12%\n\x1d\x62\x65\x63h32_account_address_prefix\x18\x01 \x01(\t\"%\n\rMsgDescriptor\x12\x14\n\x0cmsg_type_url\x18\x01 \x01(\t\"\x1b\n\x19GetAuthnDescriptorRequest\"]\n\x1aGetAuthnDescriptorResponse\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\"\x1b\n\x19GetChainDescriptorRequest\"]\n\x1aGetChainDescriptorResponse\x12?\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\"\x1b\n\x19GetCodecDescriptorRequest\"]\n\x1aGetCodecDescriptorResponse\x12?\n\x05\x63odec\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\"#\n!GetConfigurationDescriptorRequest\"n\n\"GetConfigurationDescriptorResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\"#\n!GetQueryServicesDescriptorRequest\"o\n\"GetQueryServicesDescriptorResponse\x12I\n\x07queries\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\"\x18\n\x16GetTxDescriptorRequest\"T\n\x17GetTxDescriptorResponse\x12\x39\n\x02tx\x18\x01 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"j\n\x17QueryServicesDescriptor\x12O\n\x0equery_services\x18\x01 \x03(\x0b\x32\x37.cosmos.base.reflection.v2alpha1.QueryServiceDescriptor\"\x86\x01\n\x16QueryServiceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x11\n\tis_module\x18\x02 \x01(\x08\x12G\n\x07methods\x18\x03 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.QueryMethodDescriptor\">\n\x15QueryMethodDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ull_query_path\x18\x02 \x01(\t2\xa7\n\n\x11ReflectionService\x12\xcb\x01\n\x12GetAuthnDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/authn\x12\xcb\x01\n\x12GetChainDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/chain\x12\xcb\x01\n\x12GetCodecDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/codec\x12\xeb\x01\n\x1aGetConfigurationDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/configuration\x12\xec\x01\n\x1aGetQueryServicesDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/base/reflection/v1beta1/app_descriptor/query_services\x12\xca\x01\n\x0fGetTxDescriptor\x12\x37.cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest\x1a\x38.cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptorB>Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1b\x06proto3')



_APPDESCRIPTOR = DESCRIPTOR.message_types_by_name['AppDescriptor']
_TXDESCRIPTOR = DESCRIPTOR.message_types_by_name['TxDescriptor']
_AUTHNDESCRIPTOR = DESCRIPTOR.message_types_by_name['AuthnDescriptor']
_SIGNINGMODEDESCRIPTOR = DESCRIPTOR.message_types_by_name['SigningModeDescriptor']
_CHAINDESCRIPTOR = DESCRIPTOR.message_types_by_name['ChainDescriptor']
_CODECDESCRIPTOR = DESCRIPTOR.message_types_by_name['CodecDescriptor']
_INTERFACEDESCRIPTOR = DESCRIPTOR.message_types_by_name['InterfaceDescriptor']
_INTERFACEIMPLEMENTERDESCRIPTOR = DESCRIPTOR.message_types_by_name['InterfaceImplementerDescriptor']
_INTERFACEACCEPTINGMESSAGEDESCRIPTOR = DESCRIPTOR.message_types_by_name['InterfaceAcceptingMessageDescriptor']
_CONFIGURATIONDESCRIPTOR = DESCRIPTOR.message_types_by_name['ConfigurationDescriptor']
_MSGDESCRIPTOR = DESCRIPTOR.message_types_by_name['MsgDescriptor']
_GETAUTHNDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetAuthnDescriptorRequest']
_GETAUTHNDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetAuthnDescriptorResponse']
_GETCHAINDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetChainDescriptorRequest']
_GETCHAINDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetChainDescriptorResponse']
_GETCODECDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetCodecDescriptorRequest']
_GETCODECDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetCodecDescriptorResponse']
_GETCONFIGURATIONDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorRequest']
_GETCONFIGURATIONDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorResponse']
_GETQUERYSERVICESDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorRequest']
_GETQUERYSERVICESDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorResponse']
_GETTXDESCRIPTORREQUEST = DESCRIPTOR.message_types_by_name['GetTxDescriptorRequest']
_GETTXDESCRIPTORRESPONSE = DESCRIPTOR.message_types_by_name['GetTxDescriptorResponse']
_QUERYSERVICESDESCRIPTOR = DESCRIPTOR.message_types_by_name['QueryServicesDescriptor']
_QUERYSERVICEDESCRIPTOR = DESCRIPTOR.message_types_by_name['QueryServiceDescriptor']
_QUERYMETHODDESCRIPTOR = DESCRIPTOR.message_types_by_name['QueryMethodDescriptor']
AppDescriptor = _reflection.GeneratedProtocolMessageType('AppDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _APPDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AppDescriptor)
  })
_sym_db.RegisterMessage(AppDescriptor)

TxDescriptor = _reflection.GeneratedProtocolMessageType('TxDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _TXDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.TxDescriptor)
  })
_sym_db.RegisterMessage(TxDescriptor)

AuthnDescriptor = _reflection.GeneratedProtocolMessageType('AuthnDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _AUTHNDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AuthnDescriptor)
  })
_sym_db.RegisterMessage(AuthnDescriptor)

SigningModeDescriptor = _reflection.GeneratedProtocolMessageType('SigningModeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGMODEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.SigningModeDescriptor)
  })
_sym_db.RegisterMessage(SigningModeDescriptor)

ChainDescriptor = _reflection.GeneratedProtocolMessageType('ChainDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CHAINDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ChainDescriptor)
  })
_sym_db.RegisterMessage(ChainDescriptor)

CodecDescriptor = _reflection.GeneratedProtocolMessageType('CodecDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CODECDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.CodecDescriptor)
  })
_sym_db.RegisterMessage(CodecDescriptor)

InterfaceDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceDescriptor)
  })
_sym_db.RegisterMessage(InterfaceDescriptor)

InterfaceImplementerDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceImplementerDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEIMPLEMENTERDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor)
  })
_sym_db.RegisterMessage(InterfaceImplementerDescriptor)

InterfaceAcceptingMessageDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceAcceptingMessageDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEACCEPTINGMESSAGEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor)
  })
_sym_db.RegisterMessage(InterfaceAcceptingMessageDescriptor)

ConfigurationDescriptor = _reflection.GeneratedProtocolMessageType('ConfigurationDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ConfigurationDescriptor)
  })
_sym_db.RegisterMessage(ConfigurationDescriptor)

MsgDescriptor = _reflection.GeneratedProtocolMessageType('MsgDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _MSGDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.MsgDescriptor)
  })
_sym_db.RegisterMessage(MsgDescriptor)

GetAuthnDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorRequest)

GetAuthnDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorResponse)

GetChainDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetChainDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest)
  })
_sym_db.RegisterMessage(GetChainDescriptorRequest)

GetChainDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetChainDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse)
  })
_sym_db.RegisterMessage(GetChainDescriptorResponse)

GetCodecDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest)
  })
_sym_db.RegisterMessage(GetCodecDescriptorRequest)

GetCodecDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse)
  })
_sym_db.RegisterMessage(GetCodecDescriptorResponse)

GetConfigurationDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorRequest)

GetConfigurationDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorResponse)

GetQueryServicesDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorRequest)

GetQueryServicesDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorResponse)

GetTxDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetTxDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest)
  })
_sym_db.RegisterMessage(GetTxDescriptorRequest)

GetTxDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetTxDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse)
  })
_sym_db.RegisterMessage(GetTxDescriptorResponse)

QueryServicesDescriptor = _reflection.GeneratedProtocolMessageType('QueryServicesDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICESDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServicesDescriptor)
  })
_sym_db.RegisterMessage(QueryServicesDescriptor)

QueryServiceDescriptor = _reflection.GeneratedProtocolMessageType('QueryServiceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServiceDescriptor)
  })
_sym_db.RegisterMessage(QueryServiceDescriptor)

QueryMethodDescriptor = _reflection.GeneratedProtocolMessageType('QueryMethodDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMETHODDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryMethodDescriptor)
  })
_sym_db.RegisterMessage(QueryMethodDescriptor)

_REFLECTIONSERVICE = DESCRIPTOR.services_by_name['ReflectionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1'
  _REFLECTIONSERVICE.methods_by_name['GetAuthnDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetAuthnDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/authn'
  _REFLECTIONSERVICE.methods_by_name['GetChainDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetChainDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/chain'
  _REFLECTIONSERVICE.methods_by_name['GetCodecDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetCodecDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/codec'
  _REFLECTIONSERVICE.methods_by_name['GetConfigurationDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetConfigurationDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/configuration'
  _REFLECTIONSERVICE.methods_by_name['GetQueryServicesDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetQueryServicesDescriptor']._serialized_options = b'\202\323\344\223\002?\022=/cosmos/base/reflection/v1beta1/app_descriptor/query_services'
  _REFLECTIONSERVICE.methods_by_name['GetTxDescriptor']._options = None
  _REFLECTIONSERVICE.methods_by_name['GetTxDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor'
  _APPDESCRIPTOR._serialized_start=116
  _APPDESCRIPTOR._serialized_end=548
  _TXDESCRIPTOR._serialized_start=550
  _TXDESCRIPTOR._serialized_end=644
  _AUTHNDESCRIPTOR._serialized_start=646
  _AUTHNDESCRIPTOR._serialized_end=739
  _SIGNINGMODEDESCRIPTOR._serialized_start=741
  _SIGNINGMODEDESCRIPTOR._serialized_end=839
  _CHAINDESCRIPTOR._serialized_start=841
  _CHAINDESCRIPTOR._serialized_end=870
  _CODECDESCRIPTOR._serialized_start=872
  _CODECDESCRIPTOR._serialized_end=963
  _INTERFACEDESCRIPTOR._serialized_start=966
  _INTERFACEDESCRIPTOR._serialized_end=1210
  _INTERFACEIMPLEMENTERDESCRIPTOR._serialized_start=1212
  _INTERFACEIMPLEMENTERDESCRIPTOR._serialized_end=1280
  _INTERFACEACCEPTINGMESSAGEDESCRIPTOR._serialized_start=1282
  _INTERFACEACCEPTINGMESSAGEDESCRIPTOR._serialized_end=1369
  _CONFIGURATIONDESCRIPTOR._serialized_start=1371
  _CONFIGURATIONDESCRIPTOR._serialized_end=1435
  _MSGDESCRIPTOR._serialized_start=1437
  _MSGDESCRIPTOR._serialized_end=1474
  _GETAUTHNDESCRIPTORREQUEST._serialized_start=1476
  _GETAUTHNDESCRIPTORREQUEST._serialized_end=1503
  _GETAUTHNDESCRIPTORRESPONSE._serialized_start=1505
  _GETAUTHNDESCRIPTORRESPONSE._serialized_end=1598
  _GETCHAINDESCRIPTORREQUEST._serialized_start=1600
  _GETCHAINDESCRIPTORREQUEST._serialized_end=1627
  _GETCHAINDESCRIPTORRESPONSE._serialized_start=1629
  _GETCHAINDESCRIPTORRESPONSE._serialized_end=1722
  _GETCODECDESCRIPTORREQUEST._serialized_start=1724
  _GETCODECDESCRIPTORREQUEST._serialized_end=1751
  _GETCODECDESCRIPTORRESPONSE._serialized_start=1753
  _GETCODECDESCRIPTORRESPONSE._serialized_end=1846
  _GETCONFIGURATIONDESCRIPTORREQUEST._serialized_start=1848
  _GETCONFIGURATIONDESCRIPTORREQUEST._serialized_end=1883
  _GETCONFIGURATIONDESCRIPTORRESPONSE._serialized_start=1885
  _GETCONFIGURATIONDESCRIPTORRESPONSE._serialized_end=1995
  _GETQUERYSERVICESDESCRIPTORREQUEST._serialized_start=1997
  _GETQUERYSERVICESDESCRIPTORREQUEST._serialized_end=2032
  _GETQUERYSERVICESDESCRIPTORRESPONSE._serialized_start=2034
  _GETQUERYSERVICESDESCRIPTORRESPONSE._serialized_end=2145
  _GETTXDESCRIPTORREQUEST._serialized_start=2147
  _GETTXDESCRIPTORREQUEST._serialized_end=2171
  _GETTXDESCRIPTORRESPONSE._serialized_start=2173
  _GETTXDESCRIPTORRESPONSE._serialized_end=2257
  _QUERYSERVICESDESCRIPTOR._serialized_start=2259
  _QUERYSERVICESDESCRIPTOR._serialized_end=2365
  _QUERYSERVICEDESCRIPTOR._serialized_start=2368
  _QUERYSERVICEDESCRIPTOR._serialized_end=2502
  _QUERYMETHODDESCRIPTOR._serialized_start=2504
  _QUERYMETHODDESCRIPTOR._serialized_end=2566
  _REFLECTIONSERVICE._serialized_start=2569
  _REFLECTIONSERVICE._serialized_end=3888
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions
import vpool.v1.vpool_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryReserveAssetsRequest(google.protobuf.message.Message):
    """---------------------------------------- QueryReserveAssets

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_FIELD_NUMBER: builtins.int
    pair: typing.Text
    """always BASE:QUOTE, e.g. BTC:NUSD or ETH:NUSD"""

    def __init__(self,
        *,
        pair: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair",b"pair"]) -> None: ...
global___QueryReserveAssetsRequest = QueryReserveAssetsRequest

class QueryReserveAssetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    base_asset_reserve: typing.Text
    """base asset is the crypto asset, e.g. BTC or ETH"""

    quote_asset_reserve: typing.Text
    """quote asset is usually stablecoin, in our case NUSD"""

    def __init__(self,
        *,
        base_asset_reserve: typing.Text = ...,
        quote_asset_reserve: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_reserve",b"base_asset_reserve","quote_asset_reserve",b"quote_asset_reserve"]) -> None: ...
global___QueryReserveAssetsResponse = QueryReserveAssetsResponse

class QueryAllPoolsRequest(google.protobuf.message.Message):
    """---------------------------------------- QueryAllPools

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryAllPoolsRequest = QueryAllPoolsRequest

class QueryAllPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOLS_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vpool.v1.vpool_pb2.Pool]: ...
    def __init__(self,
        *,
        pools: typing.Optional[typing.Iterable[vpool.v1.vpool_pb2.Pool]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pools",b"pools"]) -> None: ...
global___QueryAllPoolsResponse = QueryAllPoolsResponse

class QueryBaseAssetPriceRequest(google.protobuf.message.Message):
    """---------------------------------------- BaseAssetPrice

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    BASE_ASSET_AMOUNT_FIELD_NUMBER: builtins.int
    pair: typing.Text
    direction: vpool.v1.vpool_pb2.Direction.ValueType
    base_asset_amount: typing.Text
    """base asset is the crypto asset, e.g. BTC or ETH"""

    def __init__(self,
        *,
        pair: typing.Text = ...,
        direction: vpool.v1.vpool_pb2.Direction.ValueType = ...,
        base_asset_amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_amount",b"base_asset_amount","direction",b"direction","pair",b"pair"]) -> None: ...
global___QueryBaseAssetPriceRequest = QueryBaseAssetPriceRequest

class QueryBaseAssetPriceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRICE_IN_QUOTE_DENOM_FIELD_NUMBER: builtins.int
    price_in_quote_denom: typing.Text
    def __init__(self,
        *,
        price_in_quote_denom: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["price_in_quote_denom",b"price_in_quote_denom"]) -> None: ...
global___QueryBaseAssetPriceResponse = QueryBaseAssetPriceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import stablecoin.params_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the stablecoin module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    MODULE_ACCOUNT_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> stablecoin.params_pb2.Params: ...
    @property
    def module_account_balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        params: typing.Optional[stablecoin.params_pb2.Params] = ...,
        module_account_balance: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_account_balance",b"module_account_balance","params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_account_balance",b"module_account_balance","params",b"params"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import common.common_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Direction:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _DirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Direction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DIRECTION_UNSPECIFIED: _Direction.ValueType  # 0
    ADD_TO_POOL: _Direction.ValueType  # 1
    REMOVE_FROM_POOL: _Direction.ValueType  # 2
class Direction(_Direction, metaclass=_DirectionEnumTypeWrapper):
    pass

DIRECTION_UNSPECIFIED: Direction.ValueType  # 0
ADD_TO_POOL: Direction.ValueType  # 1
REMOVE_FROM_POOL: Direction.ValueType  # 2
global___Direction = Direction


class _TwapCalcOption:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TwapCalcOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TwapCalcOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TWAP_CALC_OPTION_UNSPECIFIED: _TwapCalcOption.ValueType  # 0
    SPOT: _TwapCalcOption.ValueType  # 1
    """Spot price from quote asset reserve / base asset reserve"""

    QUOTE_ASSET_SWAP: _TwapCalcOption.ValueType  # 2
    """Swapping with quote assets, output denominated in base assets"""

    BASE_ASSET_SWAP: _TwapCalcOption.ValueType  # 3
    """Swapping with base assets, output denominated in quote assets"""

class TwapCalcOption(_TwapCalcOption, metaclass=_TwapCalcOptionEnumTypeWrapper):
    """Enumerates different options of calculating twap."""
    pass

TWAP_CALC_OPTION_UNSPECIFIED: TwapCalcOption.ValueType  # 0
SPOT: TwapCalcOption.ValueType  # 1
"""Spot price from quote asset reserve / base asset reserve"""

QUOTE_ASSET_SWAP: TwapCalcOption.ValueType  # 2
"""Swapping with quote assets, output denominated in base assets"""

BASE_ASSET_SWAP: TwapCalcOption.ValueType  # 3
"""Swapping with base assets, output denominated in quote assets"""

global___TwapCalcOption = TwapCalcOption


class ReserveSnapshot(google.protobuf.message.Message):
    """a snapshot of the vpool's reserves at a given point in time"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    TIMESTAMP_MS_FIELD_NUMBER: builtins.int
    BLOCK_NUMBER_FIELD_NUMBER: builtins.int
    base_asset_reserve: typing.Text
    quote_asset_reserve: typing.Text
    """quote asset is usually the margin asset, e.g. NUSD"""

    timestamp_ms: builtins.int
    """milliseconds since unix epoch"""

    block_number: builtins.int
    def __init__(self,
        *,
        base_asset_reserve: typing.Text = ...,
        quote_asset_reserve: typing.Text = ...,
        timestamp_ms: builtins.int = ...,
        block_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_reserve",b"base_asset_reserve","block_number",b"block_number","quote_asset_reserve",b"quote_asset_reserve","timestamp_ms",b"timestamp_ms"]) -> None: ...
global___ReserveSnapshot = ReserveSnapshot

class Pool(google.protobuf.message.Message):
    """A virtual pool used only for price discovery of perpetual futures contracts.
    No real liquidity exists in this pool.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_FIELD_NUMBER: builtins.int
    BASE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    TRADE_LIMIT_RATIO_FIELD_NUMBER: builtins.int
    FLUCTUATION_LIMIT_RATIO_FIELD_NUMBER: builtins.int
    MAX_ORACLE_SPREAD_RATIO_FIELD_NUMBER: builtins.int
    @property
    def pair(self) -> common.common_pb2.AssetPair:
        """always BASE:QUOTE, e.g. BTC:NUSD or ETH:NUSD"""
        pass
    base_asset_reserve: typing.Text
    """base asset is the crypto asset, e.g. BTC or ETH"""

    quote_asset_reserve: typing.Text
    """quote asset is usually stablecoin, in our case NUSD"""

    trade_limit_ratio: typing.Text
    """ratio applied to reserves in order not to over trade"""

    fluctuation_limit_ratio: typing.Text
    """percentage that a single open or close position can alter the reserve amounts"""

    max_oracle_spread_ratio: typing.Text
    """max_oracle_spread_ratio"""

    def __init__(self,
        *,
        pair: typing.Optional[common.common_pb2.AssetPair] = ...,
        base_asset_reserve: typing.Text = ...,
        quote_asset_reserve: typing.Text = ...,
        trade_limit_ratio: typing.Text = ...,
        fluctuation_limit_ratio: typing.Text = ...,
        max_oracle_spread_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pair",b"pair"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_reserve",b"base_asset_reserve","fluctuation_limit_ratio",b"fluctuation_limit_ratio","max_oracle_spread_ratio",b"max_oracle_spread_ratio","pair",b"pair","quote_asset_reserve",b"quote_asset_reserve","trade_limit_ratio",b"trade_limit_ratio"]) -> None: ...
global___Pool = Pool



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/signing/v1beta1/signing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/tx/signing/v1beta1/signing.proto\x12\x19\x63osmos.tx.signing.v1beta1\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x19google/protobuf/any.proto\"Z\n\x14SignatureDescriptors\x12\x42\n\nsignatures\x18\x01 \x03(\x0b\x32..cosmos.tx.signing.v1beta1.SignatureDescriptor\"\xa4\x04\n\x13SignatureDescriptor\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x1a\x8d\x03\n\x04\x44\x61ta\x12L\n\x06single\x18\x01 \x01(\x0b\x32:.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.SingleH\x00\x12J\n\x05multi\x18\x02 \x01(\x0b\x32\x39.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.MultiH\x00\x1aN\n\x06Single\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignMode\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x1a\x93\x01\n\x05Multi\x12\x41\n\x08\x62itarray\x18\x01 \x01(\x0b\x32/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12G\n\nsignatures\x18\x02 \x03(\x0b\x32\x33.cosmos.tx.signing.v1beta1.SignatureDescriptor.DataB\x05\n\x03sum*\x8b\x01\n\x08SignMode\x12\x19\n\x15SIGN_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10SIGN_MODE_DIRECT\x10\x01\x12\x15\n\x11SIGN_MODE_TEXTUAL\x10\x02\x12\x1f\n\x1bSIGN_MODE_LEGACY_AMINO_JSON\x10\x7f\x12\x16\n\x11SIGN_MODE_EIP_191\x10\xbf\x01\x42/Z-github.com/cosmos/cosmos-sdk/types/tx/signingb\x06proto3')

_SIGNMODE = DESCRIPTOR.enum_types_by_name['SignMode']
SignMode = enum_type_wrapper.EnumTypeWrapper(_SIGNMODE)
SIGN_MODE_UNSPECIFIED = 0
SIGN_MODE_DIRECT = 1
SIGN_MODE_TEXTUAL = 2
SIGN_MODE_LEGACY_AMINO_JSON = 127
SIGN_MODE_EIP_191 = 191


_SIGNATUREDESCRIPTORS = DESCRIPTOR.message_types_by_name['SignatureDescriptors']
_SIGNATUREDESCRIPTOR = DESCRIPTOR.message_types_by_name['SignatureDescriptor']
_SIGNATUREDESCRIPTOR_DATA = _SIGNATUREDESCRIPTOR.nested_types_by_name['Data']
_SIGNATUREDESCRIPTOR_DATA_SINGLE = _SIGNATUREDESCRIPTOR_DATA.nested_types_by_name['Single']
_SIGNATUREDESCRIPTOR_DATA_MULTI = _SIGNATUREDESCRIPTOR_DATA.nested_types_by_name['Multi']
SignatureDescriptors = _reflection.GeneratedProtocolMessageType('SignatureDescriptors', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATUREDESCRIPTORS,
  '__module__' : 'cosmos.tx.signing.v1beta1.signing_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.signing.v1beta1.SignatureDescriptors)
  })
_sym_db.RegisterMessage(SignatureDescriptors)

SignatureDescriptor = _reflection.GeneratedProtocolMessageType('SignatureDescriptor', (_message.Message,), {

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {

    'Single' : _reflection.GeneratedProtocolMessageType('Single', (_message.Message,), {
      'DESCRIPTOR' : _SIGNATUREDESCRIPTOR_DATA_SINGLE,
      '__module__' : 'cosmos.tx.signing.v1beta1.signing_pb2'
      # @@protoc_insertion_point(class_scope:cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.Single)
      })
    ,

    'Multi' : _reflection.GeneratedProtocolMessageType('Multi', (_message.Message,), {
      'DESCRIPTOR' : _SIGNATUREDESCRIPTOR_DATA_MULTI,
      '__module__' : 'cosmos.tx.signing.v1beta1.signing_pb2'
      # @@protoc_insertion_point(class_scope:cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.Multi)
      })
    ,
    'DESCRIPTOR' : _SIGNATUREDESCRIPTOR_DATA,
    '__module__' : 'cosmos.tx.signing.v1beta1.signing_pb2'
    # @@protoc_insertion_point(class_scope:cosmos.tx.signing.v1beta1.SignatureDescriptor.Data)
    })
  ,
  'DESCRIPTOR' : _SIGNATUREDESCRIPTOR,
  '__module__' : 'cosmos.tx.signing.v1beta1.signing_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.signing.v1beta1.SignatureDescriptor)
  })
_sym_db.RegisterMessage(SignatureDescriptor)
_sym_db.RegisterMessage(SignatureDescriptor.Data)
_sym_db.RegisterMessage(SignatureDescriptor.Data.Single)
_sym_db.RegisterMessage(SignatureDescriptor.Data.Multi)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/types/tx/signing'
  _SIGNMODE._serialized_start=788
  _SIGNMODE._serialized_end=927
  _SIGNATUREDESCRIPTORS._serialized_start=144
  _SIGNATUREDESCRIPTORS._serialized_end=234
  _SIGNATUREDESCRIPTOR._serialized_start=237
  _SIGNATUREDESCRIPTOR._serialized_end=785
  _SIGNATUREDESCRIPTOR_DATA._serialized_start=388
  _SIGNATUREDESCRIPTOR_DATA._serialized_end=785
  _SIGNATUREDESCRIPTOR_DATA_SINGLE._serialized_start=550
  _SIGNATUREDESCRIPTOR_DATA_SINGLE._serialized_end=628
  _SIGNATUREDESCRIPTOR_DATA_MULTI._serialized_start=631
  _SIGNATUREDESCRIPTOR_DATA_MULTI._serialized_end=778
# @@protoc_insertion_point(module_scope)



from .client import Client
from .network import Network
from .sdk import Sdk
from .composer import Composer
from .transaction import Transaction
from .wallet import PrivateKey, PublicKey, Address
from .common import PoolAsset, Side, TxConfig


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryBalanceRequest(google.protobuf.message.Message):
    """QueryBalanceRequest is the request type for the Query/Balance RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address is the address to query balances for."""

    denom: typing.Text
    """denom is the coin denom to query balances for."""

    def __init__(self,
        *,
        address: typing.Text = ...,
        denom: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","denom",b"denom"]) -> None: ...
global___QueryBalanceRequest = QueryBalanceRequest

class QueryBalanceResponse(google.protobuf.message.Message):
    """QueryBalanceResponse is the response type for the Query/Balance RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BALANCE_FIELD_NUMBER: builtins.int
    @property
    def balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """balance is the balance of the coin."""
        pass
    def __init__(self,
        *,
        balance: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["balance",b"balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance",b"balance"]) -> None: ...
global___QueryBalanceResponse = QueryBalanceResponse

class QueryAllBalancesRequest(google.protobuf.message.Message):
    """QueryBalanceRequest is the request type for the Query/AllBalances RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address is the address to query balances for."""

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
        pass
    def __init__(self,
        *,
        address: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pagination",b"pagination"]) -> None: ...
global___QueryAllBalancesRequest = QueryAllBalancesRequest

class QueryAllBalancesResponse(google.protobuf.message.Message):
    """QueryAllBalancesResponse is the response type for the Query/AllBalances RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BALANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """balances is the balances of all the coins."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
        pass
    def __init__(self,
        *,
        balances: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balances",b"balances","pagination",b"pagination"]) -> None: ...
global___QueryAllBalancesResponse = QueryAllBalancesResponse

class QuerySpendableBalancesRequest(google.protobuf.message.Message):
    """QuerySpendableBalancesRequest defines the gRPC request structure for querying
    an account's spendable balances.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address is the address to query spendable balances for."""

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
        pass
    def __init__(self,
        *,
        address: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pagination",b"pagination"]) -> None: ...
global___QuerySpendableBalancesRequest = QuerySpendableBalancesRequest

class QuerySpendableBalancesResponse(google.protobuf.message.Message):
    """QuerySpendableBalancesResponse defines the gRPC response structure for querying
    an account's spendable balances.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BALANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """balances is the spendable balances of all the coins."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
        pass
    def __init__(self,
        *,
        balances: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balances",b"balances","pagination",b"pagination"]) -> None: ...
global___QuerySpendableBalancesResponse = QuerySpendableBalancesResponse

class QueryTotalSupplyRequest(google.protobuf.message.Message):
    """QueryTotalSupplyRequest is the request type for the Query/TotalSupply RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request.

        Since: cosmos-sdk 0.43
        """
        pass
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___QueryTotalSupplyRequest = QueryTotalSupplyRequest

class QueryTotalSupplyResponse(google.protobuf.message.Message):
    """QueryTotalSupplyResponse is the response type for the Query/TotalSupply RPC
    method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUPPLY_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """supply is the supply of the coins"""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response.

        Since: cosmos-sdk 0.43
        """
        pass
    def __init__(self,
        *,
        supply: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination","supply",b"supply"]) -> None: ...
global___QueryTotalSupplyResponse = QueryTotalSupplyResponse

class QuerySupplyOfRequest(google.protobuf.message.Message):
    """QuerySupplyOfRequest is the request type for the Query/SupplyOf RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    denom: typing.Text
    """denom is the coin denom to query balances for."""

    def __init__(self,
        *,
        denom: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom",b"denom"]) -> None: ...
global___QuerySupplyOfRequest = QuerySupplyOfRequest

class QuerySupplyOfResponse(google.protobuf.message.Message):
    """QuerySupplyOfResponse is the response type for the Query/SupplyOf RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """amount is the supply of the coin."""
        pass
    def __init__(self,
        *,
        amount: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___QuerySupplyOfResponse = QuerySupplyOfResponse

class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest defines the request type for querying x/bank parameters."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse defines the response type for querying x/bank parameters."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params: ...
    def __init__(self,
        *,
        params: typing.Optional[cosmos.bank.v1beta1.bank_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryDenomsMetadataRequest(google.protobuf.message.Message):
    """QueryDenomsMetadataRequest is the request type for the Query/DenomsMetadata RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
        pass
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___QueryDenomsMetadataRequest = QueryDenomsMetadataRequest

class QueryDenomsMetadataResponse(google.protobuf.message.Message):
    """QueryDenomsMetadataResponse is the response type for the Query/DenomsMetadata RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    METADATAS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def metadatas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]:
        """metadata provides the client information for all the registered tokens."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
        pass
    def __init__(self,
        *,
        metadatas: typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadatas",b"metadatas","pagination",b"pagination"]) -> None: ...
global___QueryDenomsMetadataResponse = QueryDenomsMetadataResponse

class QueryDenomMetadataRequest(google.protobuf.message.Message):
    """QueryDenomMetadataRequest is the request type for the Query/DenomMetadata RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    denom: typing.Text
    """denom is the coin denom to query the metadata for."""

    def __init__(self,
        *,
        denom: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom",b"denom"]) -> None: ...
global___QueryDenomMetadataRequest = QueryDenomMetadataRequest

class QueryDenomMetadataResponse(google.protobuf.message.Message):
    """QueryDenomMetadataResponse is the response type for the Query/DenomMetadata RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> cosmos.bank.v1beta1.bank_pb2.Metadata:
        """metadata describes and provides all the client information for the requested token."""
        pass
    def __init__(self,
        *,
        metadata: typing.Optional[cosmos.bank.v1beta1.bank_pb2.Metadata] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata",b"metadata"]) -> None: ...
global___QueryDenomMetadataResponse = QueryDenomMetadataResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import perp.v1.state_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryParamsRequest(google.protobuf.message.Message):
    """---------------------------------------- Params

    QueryParamsRequest is request type for the Query/Params RPC method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is response type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> perp.v1.state_pb2.Params:
        """params holds all the parameters of this module."""
        pass
    def __init__(self,
        *,
        params: typing.Optional[perp.v1.state_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryTraderPositionRequest(google.protobuf.message.Message):
    """---------------------------------------- TraderPosition

    QueryTraderPositionRequest is the request type for the position of the 
    x/perp module account.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    TRADER_FIELD_NUMBER: builtins.int
    token_pair: typing.Text
    trader: typing.Text
    def __init__(self,
        *,
        token_pair: typing.Text = ...,
        trader: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_pair",b"token_pair","trader",b"trader"]) -> None: ...
global___QueryTraderPositionRequest = QueryTraderPositionRequest

class QueryTraderPositionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POSITION_FIELD_NUMBER: builtins.int
    POSITION_NOTIONAL_FIELD_NUMBER: builtins.int
    UNREALIZED_PNL_FIELD_NUMBER: builtins.int
    MARGIN_RATIO_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> perp.v1.state_pb2.Position:
        """The position as it exists in the blockchain state"""
        pass
    position_notional: typing.Text
    """The position's current notional value, if it were to be entirely closed (in margin units)."""

    unrealized_pnl: typing.Text
    """The position's unrealized PnL."""

    margin_ratio: typing.Text
    """The position's margin ratio, calculated from margin, unrealized PnL, and position notional."""

    def __init__(self,
        *,
        position: typing.Optional[perp.v1.state_pb2.Position] = ...,
        position_notional: typing.Text = ...,
        unrealized_pnl: typing.Text = ...,
        margin_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["position",b"position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["margin_ratio",b"margin_ratio","position",b"position","position_notional",b"position_notional","unrealized_pnl",b"unrealized_pnl"]) -> None: ...
global___QueryTraderPositionResponse = QueryTraderPositionResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import lockup.v1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    LockedCoins: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLockedCoinsRequest,
        lockup.v1.query_pb2.QueryLockedCoinsResponse]

    Lock: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLockRequest,
        lockup.v1.query_pb2.QueryLockResponse]

    LocksByAddress: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLocksByAddress,
        lockup.v1.query_pb2.QueryLocksByAddressResponse]


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def LockedCoins(self,
        request: lockup.v1.query_pb2.QueryLockedCoinsRequest,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLockedCoinsResponse: ...

    @abc.abstractmethod
    def Lock(self,
        request: lockup.v1.query_pb2.QueryLockRequest,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLockResponse: ...

    @abc.abstractmethod
    def LocksByAddress(self,
        request: lockup.v1.query_pb2.QueryLocksByAddress,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLocksByAddressResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



from grpc import Channel
from nibiru.proto.perp.v1 import (
    query_pb2_grpc as perp_query,
    query_pb2 as perp_type,
)

class Perp:
    """
    Perp allows to query the endpoints made available by the Nibiru Chain's PERP module.
    """
    def __init__(
        self,
        channel: Channel
    ):
        self.api = perp_query.QueryStub(channel)

    async def params(self):
        req = perp_type.QueryParamsRequest()
        return await self.api.Params(req)

    async def trader_position(self, token_pair: str, trader: str):
        req = perp_type.QueryTraderPositionRequest(
            token_pair = token_pair,
            trader = trader,
        )
        return await self.api.TraderPosition(req)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import pricefeed.query_pb2

class QueryStub:
    """Query defines the gRPC querier service for pricefeed module"""
    def __init__(self, channel: grpc.Channel) -> None: ...
    QueryParams: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryParamsRequest,
        pricefeed.query_pb2.QueryParamsResponse]
    """QueryParams queries all parameters of the pricefeed module."""

    QueryPrice: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryPriceRequest,
        pricefeed.query_pb2.QueryPriceResponse]
    """QueryPrice queries price details for a pair"""

    QueryPrices: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryPricesRequest,
        pricefeed.query_pb2.QueryPricesResponse]
    """QueryPrices queries all prices"""

    QueryRawPrices: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryRawPricesRequest,
        pricefeed.query_pb2.QueryRawPricesResponse]
    """QueryRawPrices queries all raw prices for an asset pair"""

    QueryOracles: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryOraclesRequest,
        pricefeed.query_pb2.QueryOraclesResponse]
    """QueryOracles queries all oracles for an asset pair"""

    QueryMarkets: grpc.UnaryUnaryMultiCallable[
        pricefeed.query_pb2.QueryMarketsRequest,
        pricefeed.query_pb2.QueryMarketsResponse]
    """QueryMarkets queries all markets"""


class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service for pricefeed module"""
    @abc.abstractmethod
    def QueryParams(self,
        request: pricefeed.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryParamsResponse:
        """QueryParams queries all parameters of the pricefeed module."""
        pass

    @abc.abstractmethod
    def QueryPrice(self,
        request: pricefeed.query_pb2.QueryPriceRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryPriceResponse:
        """QueryPrice queries price details for a pair"""
        pass

    @abc.abstractmethod
    def QueryPrices(self,
        request: pricefeed.query_pb2.QueryPricesRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryPricesResponse:
        """QueryPrices queries all prices"""
        pass

    @abc.abstractmethod
    def QueryRawPrices(self,
        request: pricefeed.query_pb2.QueryRawPricesRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryRawPricesResponse:
        """QueryRawPrices queries all raw prices for an asset pair"""
        pass

    @abc.abstractmethod
    def QueryOracles(self,
        request: pricefeed.query_pb2.QueryOraclesRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryOraclesResponse:
        """QueryOracles queries all oracles for an asset pair"""
        pass

    @abc.abstractmethod
    def QueryMarkets(self,
        request: pricefeed.query_pb2.QueryMarketsRequest,
        context: grpc.ServicerContext,
    ) -> pricefeed.query_pb2.QueryMarketsResponse:
        """QueryMarkets queries all markets"""
        pass


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState contains a set of fee allowances, persisted from the store"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ALLOWANCES_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]: ...
    def __init__(self,
        *,
        allowances: typing.Optional[typing.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances",b"allowances"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EventGrant(google.protobuf.message.Message):
    """EventGrant is emitted on Msg/Grant"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: typing.Text
    """Msg type URL for which an autorization is granted"""

    granter: typing.Text
    """Granter account address"""

    grantee: typing.Text
    """Grantee account address"""

    def __init__(self,
        *,
        msg_type_url: typing.Text = ...,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","granter",b"granter","msg_type_url",b"msg_type_url"]) -> None: ...
global___EventGrant = EventGrant

class EventRevoke(google.protobuf.message.Message):
    """EventRevoke is emitted on Msg/Revoke"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: typing.Text
    """Msg type URL for which an autorization is revoked"""

    granter: typing.Text
    """Granter account address"""

    grantee: typing.Text
    """Grantee account address"""

    def __init__(self,
        *,
        msg_type_url: typing.Text = ...,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","granter",b"granter","msg_type_url",b"msg_type_url"]) -> None: ...
global___EventRevoke = EventRevoke



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Params(google.protobuf.message.Message):
    """Params defines the parameters for the module."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___Params = Params

class CurrentTWAP(google.protobuf.message.Message):
    """CurrentTWAP states defines the numerator and denominator for the TWAP calculation"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    NUMERATOR_FIELD_NUMBER: builtins.int
    DENOMINATOR_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    numerator: typing.Text
    denominator: typing.Text
    price: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        numerator: typing.Text = ...,
        denominator: typing.Text = ...,
        price: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denominator",b"denominator","numerator",b"numerator","pair_id",b"pair_id","price",b"price"]) -> None: ...
global___CurrentTWAP = CurrentTWAP



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

INTERFACE_TYPE_FIELD_NUMBER: builtins.int
IMPLEMENTS_INTERFACE_FIELD_NUMBER: builtins.int
ACCEPTS_INTERFACE_FIELD_NUMBER: builtins.int
interface_type: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, typing.Text]

implements_interface: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, typing.Text]

accepts_interface: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, typing.Text]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Http(google.protobuf.message.Message):
    """Defines the HTTP configuration for an API service. It contains a list of
    [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method
    to one or more HTTP REST API methods.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RULES_FIELD_NUMBER: builtins.int
    FULLY_DECODE_RESERVED_EXPANSION_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpRule]:
        """A list of HTTP configuration rules that apply to individual API methods.

        **NOTE:** All service configuration rules follow "last one wins" order.
        """
        pass
    fully_decode_reserved_expansion: builtins.bool
    """When set to true, URL path parmeters will be fully URI-decoded except in
    cases of single segment matches in reserved expansion, where "%2F" will be
    left encoded.

    The default behavior is to not decode RFC 6570 reserved characters in multi
    segment matches.
    """

    def __init__(self,
        *,
        rules: typing.Optional[typing.Iterable[global___HttpRule]] = ...,
        fully_decode_reserved_expansion: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fully_decode_reserved_expansion",b"fully_decode_reserved_expansion","rules",b"rules"]) -> None: ...
global___Http = Http

class HttpRule(google.protobuf.message.Message):
    """`HttpRule` defines the mapping of an RPC method to one or more HTTP
    REST API methods. The mapping specifies how different portions of the RPC
    request message are mapped to URL path, URL query parameters, and
    HTTP request body. The mapping is typically specified as an
    `google.api.http` annotation on the RPC method,
    see "google/api/annotations.proto" for details.

    The mapping consists of a field specifying the path template and
    method kind.  The path template can refer to fields in the request
    message, as in the example below which describes a REST GET
    operation on a resource collection of messages:


        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http).get = "/v1/messages/{message_id}/{sub.subfield}";
          }
        }
        message GetMessageRequest {
          message SubMessage {
            string subfield = 1;
          }
          string message_id = 1; // mapped to the URL
          SubMessage sub = 2;    // `sub.subfield` is url-mapped
        }
        message Message {
          string text = 1; // content of the resource
        }

    The same http annotation can alternatively be expressed inside the
    `GRPC API Configuration` YAML file.

        http:
          rules:
            - selector: <proto_package_name>.Messaging.GetMessage
              get: /v1/messages/{message_id}/{sub.subfield}

    This definition enables an automatic, bidrectional mapping of HTTP
    JSON to RPC. Example:

    HTTP | RPC
    -----|-----
    `GET /v1/messages/123456/foo`  | `GetMessage(message_id: "123456" sub: SubMessage(subfield: "foo"))`

    In general, not only fields but also field paths can be referenced
    from a path pattern. Fields mapped to the path pattern cannot be
    repeated and must have a primitive (non-message) type.

    Any fields in the request message which are not bound by the path
    pattern automatically become (optional) HTTP query
    parameters. Assume the following definition of the request message:


        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http).get = "/v1/messages/{message_id}";
          }
        }
        message GetMessageRequest {
          message SubMessage {
            string subfield = 1;
          }
          string message_id = 1; // mapped to the URL
          int64 revision = 2;    // becomes a parameter
          SubMessage sub = 3;    // `sub.subfield` becomes a parameter
        }


    This enables a HTTP JSON to RPC mapping as below:

    HTTP | RPC
    -----|-----
    `GET /v1/messages/123456?revision=2&sub.subfield=foo` | `GetMessage(message_id: "123456" revision: 2 sub: SubMessage(subfield: "foo"))`

    Note that fields which are mapped to HTTP parameters must have a
    primitive type or a repeated primitive type. Message types are not
    allowed. In the case of a repeated type, the parameter can be
    repeated in the URL, as in `...?param=A&param=B`.

    For HTTP method kinds which allow a request body, the `body` field
    specifies the mapping. Consider a REST update method on the
    message resource collection:


        service Messaging {
          rpc UpdateMessage(UpdateMessageRequest) returns (Message) {
            option (google.api.http) = {
              put: "/v1/messages/{message_id}"
              body: "message"
            };
          }
        }
        message UpdateMessageRequest {
          string message_id = 1; // mapped to the URL
          Message message = 2;   // mapped to the body
        }


    The following HTTP JSON to RPC mapping is enabled, where the
    representation of the JSON in the request body is determined by
    protos JSON encoding:

    HTTP | RPC
    -----|-----
    `PUT /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id: "123456" message { text: "Hi!" })`

    The special name `*` can be used in the body mapping to define that
    every field not bound by the path template should be mapped to the
    request body.  This enables the following alternative definition of
    the update method:

        service Messaging {
          rpc UpdateMessage(Message) returns (Message) {
            option (google.api.http) = {
              put: "/v1/messages/{message_id}"
              body: "*"
            };
          }
        }
        message Message {
          string message_id = 1;
          string text = 2;
        }


    The following HTTP JSON to RPC mapping is enabled:

    HTTP | RPC
    -----|-----
    `PUT /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id: "123456" text: "Hi!")`

    Note that when using `*` in the body mapping, it is not possible to
    have HTTP parameters, as all fields not bound by the path end in
    the body. This makes this option more rarely used in practice of
    defining REST APIs. The common usage of `*` is in custom methods
    which don't use the URL at all for transferring data.

    It is possible to define multiple HTTP methods for one RPC by using
    the `additional_bindings` option. Example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
              get: "/v1/messages/{message_id}"
              additional_bindings {
                get: "/v1/users/{user_id}/messages/{message_id}"
              }
            };
          }
        }
        message GetMessageRequest {
          string message_id = 1;
          string user_id = 2;
        }


    This enables the following two alternative HTTP JSON to RPC
    mappings:

    HTTP | RPC
    -----|-----
    `GET /v1/messages/123456` | `GetMessage(message_id: "123456")`
    `GET /v1/users/me/messages/123456` | `GetMessage(user_id: "me" message_id: "123456")`

    # Rules for HTTP mapping

    The rules for mapping HTTP path, query parameters, and body fields
    to the request message are as follows:

    1. The `body` field specifies either `*` or a field path, or is
       omitted. If omitted, it indicates there is no HTTP request body.
    2. Leaf fields (recursive expansion of nested messages in the
       request) can be classified into three types:
        (a) Matched in the URL template.
        (b) Covered by body (if body is `*`, everything except (a) fields;
            else everything under the body field)
        (c) All other fields.
    3. URL query parameters found in the HTTP request are mapped to (c) fields.
    4. Any body sent with an HTTP request can contain only (b) fields.

    The syntax of the path template is as follows:

        Template = "/" Segments [ Verb ] ;
        Segments = Segment { "/" Segment } ;
        Segment  = "*" | "**" | LITERAL | Variable ;
        Variable = "{" FieldPath [ "=" Segments ] "}" ;
        FieldPath = IDENT { "." IDENT } ;
        Verb     = ":" LITERAL ;

    The syntax `*` matches a single path segment. The syntax `**` matches zero
    or more path segments, which must be the last part of the path except the
    `Verb`. The syntax `LITERAL` matches literal text in the path.

    The syntax `Variable` matches part of the URL path as specified by its
    template. A variable template must not contain other variables. If a variable
    matches a single path segment, its template may be omitted, e.g. `{var}`
    is equivalent to `{var=*}`.

    If a variable contains exactly one path segment, such as `"{var}"` or
    `"{var=*}"`, when such a variable is expanded into a URL path, all characters
    except `[-_.~0-9a-zA-Z]` are percent-encoded. Such variables show up in the
    Discovery Document as `{var}`.

    If a variable contains one or more path segments, such as `"{var=foo/*}"`
    or `"{var=**}"`, when such a variable is expanded into a URL path, all
    characters except `[-_.~/0-9a-zA-Z]` are percent-encoded. Such variables
    show up in the Discovery Document as `{+var}`.

    NOTE: While the single segment variable matches the semantics of
    [RFC 6570](https://tools.ietf.org/html/rfc6570) Section 3.2.2
    Simple String Expansion, the multi segment variable **does not** match
    RFC 6570 Reserved Expansion. The reason is that the Reserved Expansion
    does not expand special characters like `?` and `#`, which would lead
    to invalid URLs.

    NOTE: the field paths in variables and in the `body` must not refer to
    repeated fields or map fields.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SELECTOR_FIELD_NUMBER: builtins.int
    GET_FIELD_NUMBER: builtins.int
    PUT_FIELD_NUMBER: builtins.int
    POST_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    PATCH_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    RESPONSE_BODY_FIELD_NUMBER: builtins.int
    ADDITIONAL_BINDINGS_FIELD_NUMBER: builtins.int
    selector: typing.Text
    """Selects methods to which this rule applies.

    Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
    """

    get: typing.Text
    """Used for listing and getting information about resources."""

    put: typing.Text
    """Used for updating a resource."""

    post: typing.Text
    """Used for creating a resource."""

    delete: typing.Text
    """Used for deleting a resource."""

    patch: typing.Text
    """Used for updating a resource."""

    @property
    def custom(self) -> global___CustomHttpPattern:
        """The custom pattern is used for specifying an HTTP method that is not
        included in the `pattern` field, such as HEAD, or "*" to leave the
        HTTP method unspecified for this rule. The wild-card rule is useful
        for services that provide content to Web (HTML) clients.
        """
        pass
    body: typing.Text
    """The name of the request field whose value is mapped to the HTTP body, or
    `*` for mapping all fields not captured by the path pattern to the HTTP
    body. NOTE: the referred field must not be a repeated field and must be
    present at the top-level of request message type.
    """

    response_body: typing.Text
    """Optional. The name of the response field whose value is mapped to the HTTP
    body of response. Other response fields are ignored. When
    not set, the response message will be used as HTTP body of response.
    """

    @property
    def additional_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpRule]:
        """Additional HTTP bindings for the selector. Nested bindings must
        not contain an `additional_bindings` field themselves (that is,
        the nesting may only be one level deep).
        """
        pass
    def __init__(self,
        *,
        selector: typing.Text = ...,
        get: typing.Text = ...,
        put: typing.Text = ...,
        post: typing.Text = ...,
        delete: typing.Text = ...,
        patch: typing.Text = ...,
        custom: typing.Optional[global___CustomHttpPattern] = ...,
        body: typing.Text = ...,
        response_body: typing.Text = ...,
        additional_bindings: typing.Optional[typing.Iterable[global___HttpRule]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom",b"custom","delete",b"delete","get",b"get","patch",b"patch","pattern",b"pattern","post",b"post","put",b"put"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_bindings",b"additional_bindings","body",b"body","custom",b"custom","delete",b"delete","get",b"get","patch",b"patch","pattern",b"pattern","post",b"post","put",b"put","response_body",b"response_body","selector",b"selector"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["pattern",b"pattern"]) -> typing.Optional[typing_extensions.Literal["get","put","post","delete","patch","custom"]]: ...
global___HttpRule = HttpRule

class CustomHttpPattern(google.protobuf.message.Message):
    """A custom pattern is used for defining custom HTTP verb."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KIND_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    kind: typing.Text
    """The name of this custom HTTP verb."""

    path: typing.Text
    """The path matched by this custom verb."""

    def __init__(self,
        *,
        kind: typing.Text = ...,
        path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind",b"kind","path",b"path"]) -> None: ...
global___CustomHttpPattern = CustomHttpPattern



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PubKey(google.protobuf.message.Message):
    """PubKey defines a secp256r1 ECDSA public key."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """Point on secp256r1 curve in a compressed representation as specified in section
    4.3.6 of ANSI X9.62: https://webstore.ansi.org/standards/ascx9/ansix9621998
    """

    def __init__(self,
        *,
        key: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key"]) -> None: ...
global___PubKey = PubKey

class PrivKey(google.protobuf.message.Message):
    """PrivKey defines a secp256r1 ECDSA private key."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SECRET_FIELD_NUMBER: builtins.int
    secret: builtins.bytes
    """secret number serialized using big-endian encoding"""

    def __init__(self,
        *,
        secret: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret",b"secret"]) -> None: ...
global___PrivKey = PrivKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import tendermint.p2p.types_pb2
import tendermint.types.block_pb2
import tendermint.types.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetValidatorSetByHeightRequest(google.protobuf.message.Message):
    """GetValidatorSetByHeightRequest is the request type for the Query/GetValidatorSetByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HEIGHT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    height: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
        pass
    def __init__(self,
        *,
        height: builtins.int = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","pagination",b"pagination"]) -> None: ...
global___GetValidatorSetByHeightRequest = GetValidatorSetByHeightRequest

class GetValidatorSetByHeightResponse(google.protobuf.message.Message):
    """GetValidatorSetByHeightResponse is the response type for the Query/GetValidatorSetByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
        pass
    def __init__(self,
        *,
        block_height: builtins.int = ...,
        validators: typing.Optional[typing.Iterable[global___Validator]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_height",b"block_height","pagination",b"pagination","validators",b"validators"]) -> None: ...
global___GetValidatorSetByHeightResponse = GetValidatorSetByHeightResponse

class GetLatestValidatorSetRequest(google.protobuf.message.Message):
    """GetLatestValidatorSetRequest is the request type for the Query/GetValidatorSetByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
        pass
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___GetLatestValidatorSetRequest = GetLatestValidatorSetRequest

class GetLatestValidatorSetResponse(google.protobuf.message.Message):
    """GetLatestValidatorSetResponse is the response type for the Query/GetValidatorSetByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
        pass
    def __init__(self,
        *,
        block_height: builtins.int = ...,
        validators: typing.Optional[typing.Iterable[global___Validator]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_height",b"block_height","pagination",b"pagination","validators",b"validators"]) -> None: ...
global___GetLatestValidatorSetResponse = GetLatestValidatorSetResponse

class Validator(google.protobuf.message.Message):
    """Validator is the type for the validator-set."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    PROPOSER_PRIORITY_FIELD_NUMBER: builtins.int
    address: typing.Text
    @property
    def pub_key(self) -> google.protobuf.any_pb2.Any: ...
    voting_power: builtins.int
    proposer_priority: builtins.int
    def __init__(self,
        *,
        address: typing.Text = ...,
        pub_key: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        voting_power: builtins.int = ...,
        proposer_priority: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","proposer_priority",b"proposer_priority","pub_key",b"pub_key","voting_power",b"voting_power"]) -> None: ...
global___Validator = Validator

class GetBlockByHeightRequest(google.protobuf.message.Message):
    """GetBlockByHeightRequest is the request type for the Query/GetBlockByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int
    def __init__(self,
        *,
        height: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height"]) -> None: ...
global___GetBlockByHeightRequest = GetBlockByHeightRequest

class GetBlockByHeightResponse(google.protobuf.message.Message):
    """GetBlockByHeightResponse is the response type for the Query/GetBlockByHeight RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...
    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...
    def __init__(self,
        *,
        block_id: typing.Optional[tendermint.types.types_pb2.BlockID] = ...,
        block: typing.Optional[tendermint.types.block_pb2.Block] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block",b"block","block_id",b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block",b"block","block_id",b"block_id"]) -> None: ...
global___GetBlockByHeightResponse = GetBlockByHeightResponse

class GetLatestBlockRequest(google.protobuf.message.Message):
    """GetLatestBlockRequest is the request type for the Query/GetLatestBlock RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___GetLatestBlockRequest = GetLatestBlockRequest

class GetLatestBlockResponse(google.protobuf.message.Message):
    """GetLatestBlockResponse is the response type for the Query/GetLatestBlock RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...
    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...
    def __init__(self,
        *,
        block_id: typing.Optional[tendermint.types.types_pb2.BlockID] = ...,
        block: typing.Optional[tendermint.types.block_pb2.Block] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block",b"block","block_id",b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block",b"block","block_id",b"block_id"]) -> None: ...
global___GetLatestBlockResponse = GetLatestBlockResponse

class GetSyncingRequest(google.protobuf.message.Message):
    """GetSyncingRequest is the request type for the Query/GetSyncing RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___GetSyncingRequest = GetSyncingRequest

class GetSyncingResponse(google.protobuf.message.Message):
    """GetSyncingResponse is the response type for the Query/GetSyncing RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SYNCING_FIELD_NUMBER: builtins.int
    syncing: builtins.bool
    def __init__(self,
        *,
        syncing: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["syncing",b"syncing"]) -> None: ...
global___GetSyncingResponse = GetSyncingResponse

class GetNodeInfoRequest(google.protobuf.message.Message):
    """GetNodeInfoRequest is the request type for the Query/GetNodeInfo RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___GetNodeInfoRequest = GetNodeInfoRequest

class GetNodeInfoResponse(google.protobuf.message.Message):
    """GetNodeInfoResponse is the request type for the Query/GetNodeInfo RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEFAULT_NODE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def default_node_info(self) -> tendermint.p2p.types_pb2.DefaultNodeInfo: ...
    @property
    def application_version(self) -> global___VersionInfo: ...
    def __init__(self,
        *,
        default_node_info: typing.Optional[tendermint.p2p.types_pb2.DefaultNodeInfo] = ...,
        application_version: typing.Optional[global___VersionInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_version",b"application_version","default_node_info",b"default_node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_version",b"application_version","default_node_info",b"default_node_info"]) -> None: ...
global___GetNodeInfoResponse = GetNodeInfoResponse

class VersionInfo(google.protobuf.message.Message):
    """VersionInfo is the type for the GetNodeInfoResponse message."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    BUILD_TAGS_FIELD_NUMBER: builtins.int
    GO_VERSION_FIELD_NUMBER: builtins.int
    BUILD_DEPS_FIELD_NUMBER: builtins.int
    COSMOS_SDK_VERSION_FIELD_NUMBER: builtins.int
    name: typing.Text
    app_name: typing.Text
    version: typing.Text
    git_commit: typing.Text
    build_tags: typing.Text
    go_version: typing.Text
    @property
    def build_deps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]: ...
    cosmos_sdk_version: typing.Text
    """Since: cosmos-sdk 0.43"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        app_name: typing.Text = ...,
        version: typing.Text = ...,
        git_commit: typing.Text = ...,
        build_tags: typing.Text = ...,
        go_version: typing.Text = ...,
        build_deps: typing.Optional[typing.Iterable[global___Module]] = ...,
        cosmos_sdk_version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_name",b"app_name","build_deps",b"build_deps","build_tags",b"build_tags","cosmos_sdk_version",b"cosmos_sdk_version","git_commit",b"git_commit","go_version",b"go_version","name",b"name","version",b"version"]) -> None: ...
global___VersionInfo = VersionInfo

class Module(google.protobuf.message.Message):
    """Module is the type for VersionInfo"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    path: typing.Text
    """module path"""

    version: typing.Text
    """module version"""

    sum: typing.Text
    """checksum"""

    def __init__(self,
        *,
        path: typing.Text = ...,
        version: typing.Text = ...,
        sum: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path",b"path","sum",b"sum","version",b"version"]) -> None: ...
global___Module = Module



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryEvidenceRequest(google.protobuf.message.Message):
    """QueryEvidenceRequest is the request type for the Query/Evidence RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVIDENCE_HASH_FIELD_NUMBER: builtins.int
    evidence_hash: builtins.bytes
    """evidence_hash defines the hash of the requested evidence."""

    def __init__(self,
        *,
        evidence_hash: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence_hash",b"evidence_hash"]) -> None: ...
global___QueryEvidenceRequest = QueryEvidenceRequest

class QueryEvidenceResponse(google.protobuf.message.Message):
    """QueryEvidenceResponse is the response type for the Query/Evidence RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVIDENCE_FIELD_NUMBER: builtins.int
    @property
    def evidence(self) -> google.protobuf.any_pb2.Any:
        """evidence returns the requested evidence."""
        pass
    def __init__(self,
        *,
        evidence: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["evidence",b"evidence"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence",b"evidence"]) -> None: ...
global___QueryEvidenceResponse = QueryEvidenceResponse

class QueryAllEvidenceRequest(google.protobuf.message.Message):
    """QueryEvidenceRequest is the request type for the Query/AllEvidence RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
        pass
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___QueryAllEvidenceRequest = QueryAllEvidenceRequest

class QueryAllEvidenceResponse(google.protobuf.message.Message):
    """QueryAllEvidenceResponse is the response type for the Query/AllEvidence RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVIDENCE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def evidence(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """evidence returns all evidences."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
        pass
    def __init__(self,
        *,
        evidence: typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence",b"evidence","pagination",b"pagination"]) -> None: ...
global___QueryAllEvidenceResponse = QueryAllEvidenceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PageRequest(google.protobuf.message.Message):
    """PageRequest is to be embedded in gRPC request messages for efficient
    pagination. Ex:

     message SomeRequest {
             Foo some_parameter = 1;
             PageRequest pagination = 2;
     }
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    COUNT_TOTAL_FIELD_NUMBER: builtins.int
    REVERSE_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """key is a value returned in PageResponse.next_key to begin
    querying the next page most efficiently. Only one of offset or key
    should be set.
    """

    offset: builtins.int
    """offset is a numeric offset that can be used when key is unavailable.
    It is less efficient than using key. Only one of offset or key should
    be set.
    """

    limit: builtins.int
    """limit is the total number of results to be returned in the result page.
    If left empty it will default to a value to be set by each app.
    """

    count_total: builtins.bool
    """count_total is set to true  to indicate that the result set should include
    a count of the total number of items available for pagination in UIs.
    count_total is only respected when offset is used. It is ignored when key
    is set.
    """

    reverse: builtins.bool
    """reverse is set to true if results are to be returned in the descending order.

    Since: cosmos-sdk 0.43
    """

    def __init__(self,
        *,
        key: builtins.bytes = ...,
        offset: builtins.int = ...,
        limit: builtins.int = ...,
        count_total: builtins.bool = ...,
        reverse: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count_total",b"count_total","key",b"key","limit",b"limit","offset",b"offset","reverse",b"reverse"]) -> None: ...
global___PageRequest = PageRequest

class PageResponse(google.protobuf.message.Message):
    """PageResponse is to be embedded in gRPC response messages where the
    corresponding request message has used PageRequest.

     message SomeResponse {
             repeated Bar results = 1;
             PageResponse page = 2;
     }
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NEXT_KEY_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    next_key: builtins.bytes
    """next_key is the key to be passed to PageRequest.key to
    query the next page most efficiently
    """

    total: builtins.int
    """total is total number of results available if PageRequest.count_total
    was set, its value is undefined otherwise
    """

    def __init__(self,
        *,
        next_key: builtins.bytes = ...,
        total: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_key",b"next_key","total",b"total"]) -> None: ...
global___PageResponse = PageResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.slashing.v1beta1.slashing_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.slashing.v1beta1.slashing_pb2.Params: ...
    def __init__(self,
        *,
        params: typing.Optional[cosmos.slashing.v1beta1.slashing_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QuerySigningInfoRequest(google.protobuf.message.Message):
    """QuerySigningInfoRequest is the request type for the Query/SigningInfo RPC
    method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONS_ADDRESS_FIELD_NUMBER: builtins.int
    cons_address: typing.Text
    """cons_address is the address to query signing info of"""

    def __init__(self,
        *,
        cons_address: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cons_address",b"cons_address"]) -> None: ...
global___QuerySigningInfoRequest = QuerySigningInfoRequest

class QuerySigningInfoResponse(google.protobuf.message.Message):
    """QuerySigningInfoResponse is the response type for the Query/SigningInfo RPC
    method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VAL_SIGNING_INFO_FIELD_NUMBER: builtins.int
    @property
    def val_signing_info(self) -> cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo:
        """val_signing_info is the signing info of requested val cons address"""
        pass
    def __init__(self,
        *,
        val_signing_info: typing.Optional[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["val_signing_info",b"val_signing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["val_signing_info",b"val_signing_info"]) -> None: ...
global___QuerySigningInfoResponse = QuerySigningInfoResponse

class QuerySigningInfosRequest(google.protobuf.message.Message):
    """QuerySigningInfosRequest is the request type for the Query/SigningInfos RPC
    method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___QuerySigningInfosRequest = QuerySigningInfosRequest

class QuerySigningInfosResponse(google.protobuf.message.Message):
    """QuerySigningInfosResponse is the response type for the Query/SigningInfos RPC
    method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INFO_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo]:
        """info is the signing info of all validators"""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...
    def __init__(self,
        *,
        info: typing.Optional[typing.Iterable[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info",b"info","pagination",b"pagination"]) -> None: ...
global___QuerySigningInfosResponse = QuerySigningInfosResponse



from typing import List

from nibiru.proto.dex.v1 import (
    tx_pb2 as dex_tx_pb,
    pool_pb2 as pool_tx_pb,
)
from nibiru.common import PoolAsset

from nibiru.proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb


class Dex:
    @staticmethod
    def create_pool(creator: str, swap_fee: str, exit_fee: str, assets: List[PoolAsset]):
        pool_assets = [pool_tx_pb.PoolAsset(token=a.token, weight=a.weight) for a in assets]

        return dex_tx_pb.MsgCreatePool(
            creator = creator,
            poolParams = pool_tx_pb.PoolParams(swapFee=swap_fee, exitFee=exit_fee),
            poolAssets = pool_assets,
        )

    @staticmethod
    def join_pool(sender: str, pool_id: int, tokens: List[coin_pb.Coin]):
        return dex_tx_pb.MsgJoinPool(
            sender = sender,
            poolId = pool_id,
            tokensIn = tokens,
        )

    @staticmethod
    def exit_pool(sender: str, pool_id: int, pool_shares: coin_pb.Coin):
        return dex_tx_pb.MsgExitPool(
            sender = sender,
            poolId = pool_id,
            poolShares = pool_shares,
        )

    @staticmethod
    def swap_assets(sender: str, pool_id: int, token_in: coin_pb.Coin, token_out_denom):
        return dex_tx_pb.MsgSwapAssets(
            sender = sender,
            poolId = pool_id,
            tokenIn = token_in,
            tokenOutDenom = token_out_denom,
        )



# Copyright 2022 Nibiru Chain
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import asyncio
import logging

from nibiru import Client, Composer, Network, PrivateKey, Transaction
from nibiru.constant import GAS_PRICE


async def main() -> None:
    # select network: local, testnet, mainnet
    network = Network.local()

    # initialize grpc client
    client = Client(network, insecure=True)
    await client.sync_timeout_height()

    # load account
    priv_key = PrivateKey.from_mnemonic(
        "guard cream sadness conduct invite crumble clock pudding hole grit liar hotel maid produce squeeze return argue turtle know drive eight casino maze host"
    )
    pub_key = priv_key.to_public_key()
    address = await pub_key.to_address().async_init_num_seq(network.lcd_endpoint)

    # prepare tx msg
    msg = Composer.msg_send(
        from_address=address.to_acc_bech32(),
        to_address="nibi1j38z56cus02vq6f5m0mz2mygufvjss43fj34gk",
        coins=[Composer.coin(amount=5, denom="unibi")],
    )

    # build tx
    tx = (
        Transaction()
        .with_messages(msg)
        .with_sequence(address.get_sequence())
        .with_account_num(address.get_number())
        .with_chain_id(network.chain_id)
        .with_signer(priv_key)
    )
    sim_tx_raw_bytes = tx.get_signed_tx_data()

    # simulate tx
    (sim_res, success) = await client.simulate_tx(sim_tx_raw_bytes)
    if not success:
        print(sim_res)
        return

    print("Simulation response: \n", sim_res)
    # build tx
    gas_limit = sim_res.gas_info.gas_used * 1.25  # add 25% to the limit
    fee = [
        Composer.coin(
            amount=int(GAS_PRICE * gas_limit),
            denom=network.fee_denom,
        )
    ]
    tx = tx.with_gas(gas_limit).with_fee(fee).with_memo("").with_timeout_height(client.timeout_height)
    tx_raw_bytes = tx.get_signed_tx_data()

    # broadcast tx: send_tx_async_mode, send_tx_sync_mode, send_tx_block_mode
    res = await client.send_tx_block_mode(tx_raw_bytes)
    print("Transaction response: \n", res)
    print("gas wanted: {}".format(gas_limit))
    print("gas fee: {} unibi".format(res.gas_used * GAS_PRICE))


if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO)
    asyncio.get_event_loop().run_until_complete(main())



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import tendermint.crypto.keys_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValidatorSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATORS_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def proposer(self) -> global___Validator: ...
    total_voting_power: builtins.int
    def __init__(self,
        *,
        validators: typing.Optional[typing.Iterable[global___Validator]] = ...,
        proposer: typing.Optional[global___Validator] = ...,
        total_voting_power: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proposer",b"proposer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposer",b"proposer","total_voting_power",b"total_voting_power","validators",b"validators"]) -> None: ...
global___ValidatorSet = ValidatorSet

class Validator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    PROPOSER_PRIORITY_FIELD_NUMBER: builtins.int
    address: builtins.bytes
    @property
    def pub_key(self) -> tendermint.crypto.keys_pb2.PublicKey: ...
    voting_power: builtins.int
    proposer_priority: builtins.int
    def __init__(self,
        *,
        address: builtins.bytes = ...,
        pub_key: typing.Optional[tendermint.crypto.keys_pb2.PublicKey] = ...,
        voting_power: builtins.int = ...,
        proposer_priority: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","proposer_priority",b"proposer_priority","pub_key",b"pub_key","voting_power",b"voting_power"]) -> None: ...
global___Validator = Validator

class SimpleValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    @property
    def pub_key(self) -> tendermint.crypto.keys_pb2.PublicKey: ...
    voting_power: builtins.int
    def __init__(self,
        *,
        pub_key: typing.Optional[tendermint.crypto.keys_pb2.PublicKey] = ...,
        voting_power: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_key",b"pub_key","voting_power",b"voting_power"]) -> None: ...
global___SimpleValidator = SimpleValidator



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import stablecoin.params_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryParamsRequest(google.protobuf.message.Message):
    """---------------------------------------- Params

    QueryParamsRequest is request type for the Query/Params RPC method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is response type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> stablecoin.params_pb2.Params:
        """params holds all the parameters of this module."""
        pass
    def __init__(self,
        *,
        params: typing.Optional[stablecoin.params_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryModuleAccountBalances(google.protobuf.message.Message):
    """---------------------------------------- ModuleAccountBalances

    QueryModuleAccountBalances is the request type for the balance of the 
    x/stablecoin module account.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryModuleAccountBalances = QueryModuleAccountBalances

class QueryModuleAccountBalancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULEACCOUNTBALANCES_FIELD_NUMBER: builtins.int
    @property
    def moduleAccountBalances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """ModuleAccountBalances is the balance of all coins in the x/stablecoin module."""
        pass
    def __init__(self,
        *,
        moduleAccountBalances: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["moduleAccountBalances",b"moduleAccountBalances"]) -> None: ...
global___QueryModuleAccountBalancesResponse = QueryModuleAccountBalancesResponse

class QueryCirculatingSupplies(google.protobuf.message.Message):
    """---------------------------------------- CirculatingSupplies

    QueryCirculatingSupplies is the request type for the circulating supply of
    both NIBI and NUSD.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryCirculatingSupplies = QueryCirculatingSupplies

class QueryCirculatingSuppliesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NIBI_FIELD_NUMBER: builtins.int
    NUSD_FIELD_NUMBER: builtins.int
    @property
    def NIBI(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def NUSD(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        NIBI: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        NUSD: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["NIBI",b"NIBI","NUSD",b"NUSD"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["NIBI",b"NIBI","NUSD",b"NUSD"]) -> None: ...
global___QueryCirculatingSuppliesResponse = QueryCirculatingSuppliesResponse

class QueryGovToMintStable(google.protobuf.message.Message):
    """---------------------------------------- GovToMintStable

    QueryGovToMintStable is the request type for the Query/GovToMintStable RPC method
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COLLATERAL_FIELD_NUMBER: builtins.int
    @property
    def collateral(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        collateral: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collateral",b"collateral"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collateral",b"collateral"]) -> None: ...
global___QueryGovToMintStable = QueryGovToMintStable

class QueryGovToMintStableResponse(google.protobuf.message.Message):
    """QueryGovToMintStableResponse is the response type for 'QueryGovToMintStable'"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GOV_FIELD_NUMBER: builtins.int
    @property
    def gov(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        gov: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gov",b"gov"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gov",b"gov"]) -> None: ...
global___QueryGovToMintStableResponse = QueryGovToMintStableResponse

class LiquidityRatioInfo(google.protobuf.message.Message):
    """---------------------------------------- Liquidity Ratio Info

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIQUIDITY_RATIO_FIELD_NUMBER: builtins.int
    UPPER_BAND_FIELD_NUMBER: builtins.int
    LOWER_BAND_FIELD_NUMBER: builtins.int
    liquidity_ratio: typing.Text
    upper_band: typing.Text
    lower_band: typing.Text
    def __init__(self,
        *,
        liquidity_ratio: typing.Text = ...,
        upper_band: typing.Text = ...,
        lower_band: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["liquidity_ratio",b"liquidity_ratio","lower_band",b"lower_band","upper_band",b"upper_band"]) -> None: ...
global___LiquidityRatioInfo = LiquidityRatioInfo

class QueryLiquidityRatioInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryLiquidityRatioInfoRequest = QueryLiquidityRatioInfoRequest

class QueryLiquidityRatioInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INFO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___LiquidityRatioInfo: ...
    def __init__(self,
        *,
        info: typing.Optional[global___LiquidityRatioInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info",b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info",b"info"]) -> None: ...
global___QueryLiquidityRatioInfoResponse = QueryLiquidityRatioInfoResponse
